pub enum TransmitState {
Completed,
Half,
Aborted,
Failure,
}Expand description
The state of a transmission action, including sending and receiving.
Variants
Completed
The transmission completed, all data has been transmisted.
Half
Transmited data size has been over half of the buffer.
Aborted
The transmission has been aborted.
Failure
The transmission failed, may be some error occurred.